==> apache-camel-quarkus-3.15.0-src.zip: camel-quarkus-3.15.0/integration-tests/microprofile-fault-tolerance/src/test/java/org/apache/camel/quarkus/component/microprofile/it/faulttolerance/MicroProfileFaultToleranceConfigurationTestProfile.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.microprofile.it.faulttolerance;

import java.util.Map;

import io.quarkus.test.junit.QuarkusTestProfile;

public class MicroProfileFaultToleranceConfigurationTestProfile implements QuarkusTestProfile {
    @Override
    public Map<String, String> getConfigOverrides() {
        return Map.of(
                "load.config.test.route", "true",
                "camel.faulttolerance.circuitBreaker", "customCircuitBreaker",
                "camel.faulttolerance.delay", "15",
                "camel.faulttolerance.successThreshold", "4",
                "camel.faulttolerance.requestVolumeThreshold", "60",
                "camel.faulttolerance.failureRatio", "94",
                "camel.faulttolerance.timeoutEnabled", "true",
                "camel.faulttolerance.timeoutDuration", "3000",
                "camel.faulttolerance.timeoutPoolSize", "3");
    }
}

==> apache-camel-quarkus-3.20.3-src.zip: camel-quarkus-3.20.3/integration-tests/microprofile-fault-tolerance/src/test/java/org/apache/camel/quarkus/component/microprofile/it/faulttolerance/MicroProfileFaultToleranceConfigurationTestProfile.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.component.microprofile.it.faulttolerance;

import java.util.Map;

import io.quarkus.test.junit.QuarkusTestProfile;
import org.apache.camel.util.CollectionHelper;

public class MicroProfileFaultToleranceConfigurationTestProfile implements QuarkusTestProfile {
    @Override
    public Map<String, String> getConfigOverrides() {
        return CollectionHelper.mapOf(
                "load.config.test.route", "true",
                "camel.faulttolerance.circuitBreaker", "customCircuitBreaker",
                "camel.faulttolerance.bulkheadEnabled", "true",
                "camel.faulttolerance.bulkheadExecutorService", "customBulkheadExecutorService",
                "camel.faulttolerance.delay", "15",
                "camel.faulttolerance.successThreshold", "4",
                "camel.faulttolerance.requestVolumeThreshold", "60",
                "camel.faulttolerance.failureRatio", "94",
                "camel.faulttolerance.timeoutEnabled", "true",
                "camel.faulttolerance.timeoutDuration", "3000",
                "camel.faulttolerance.timeoutPoolSize", "3");
    }
}
